# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .project_notification_data import ProjectNotificationData
from ...base_types.types.qualified_count import QualifiedCount
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectNotificationsResponse(UniversalBaseModel):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.notifications import (
        Notification,
        ProjectNotificationData,
        ProjectNotificationRiskData,
        ProjectNotificationsResponse,
    )

    ProjectNotificationsResponse(
        offset=0,
        limit=20,
        next=False,
        size=QualifiedCount(
            count=3,
            qualifier="eq",
        ),
        data=[
            ProjectNotificationData(
                id="dlOL1cZzEkIEZcRUcrBZCQ",
                entity_id="dlOL1cZzEkIEZcRUcrBZCQ",
                resource_id="0eZQ43",
                notifications=[
                    Notification(
                        type="risk",
                        field="forced_labor_xinjiang_origin_subtier",
                        values=["false"],
                        date="2024-02-06T00:00:00.000Z",
                    )
                ],
                custom_fields={"properties": {"custom_name": "Victoria Beckham"}},
                risk_notifications=ProjectNotificationRiskData(
                    added=["forced_labor_xinjiang_origin_subtier"],
                    removed=[],
                    date="2024-02-06T00:00:00.000Z",
                ),
            ),
            ProjectNotificationData(
                id="wxwqZshCF4trlrmOa2eu9w",
                entity_id="wxwqZshCF4trlrmOa2eu9w",
                resource_id="03ePyj",
                notifications=[
                    Notification(
                        type="risk",
                        field="forced_labor_sheffield_hallam_university_reports_origin_subtier",
                        values=["3"],
                        date="2024-02-15T00:00:00.000Z",
                    )
                ],
                risk_notifications=ProjectNotificationRiskData(
                    added=[],
                    removed=[
                        "forced_labor_sheffield_hallam_university_reports_origin_subtier"
                    ],
                    date="2024-02-15T00:00:00.000Z",
                ),
            ),
            ProjectNotificationData(
                id="dX9cfM3FPefIp8VAuBKgIQ",
                entity_id="dX9cfM3FPefIp8VAuBKgIQ",
                resource_id="0XEQaX",
                notifications=[
                    Notification(
                        type="risk",
                        field="owner_of_regulatory_action_entity",
                        values=["1"],
                        date="2024-02-06T00:00:00.000Z",
                    ),
                    Notification(
                        type="risk",
                        field="forced_labor_sheffield_hallam_university_reports_origin_direct",
                        values=["1"],
                        date="2024-02-15T00:00:00.000Z",
                    ),
                    Notification(
                        type="risk",
                        field="forced_labor_sheffield_hallam_university_reports_origin_subtier",
                        values=["false"],
                        date="2024-02-15T00:00:00.000Z",
                    ),
                ],
                custom_fields={"properties": {"custom_identifier": "abc123"}},
                risk_notifications=ProjectNotificationRiskData(
                    added=[
                        "forced_labor_sheffield_hallam_university_reports_origin_subtier"
                    ],
                    removed=[
                        "owner_of_regulatory_action_entity",
                        "forced_labor_sheffield_hallam_university_reports_origin_direct",
                    ],
                    date="2024-02-15T00:00:00.000Z",
                ),
            ),
        ],
    )
    """

    offset: int
    limit: int
    next: bool
    data: typing.List[ProjectNotificationData]
    size: QualifiedCount

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
import typing_extensions
from ...core.serialization import FieldMetadata
from .tag import Tag
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class RiskIntelligenceProperties(UniversalBaseModel):
    authority: typing.Optional[str] = pydantic.Field(default=None)
    """
    Government authority issuing the enforcement or risk intelligence action
    """

    date: typing.Optional[str] = pydantic.Field(default=None)
    """
    as-of date
    """

    from_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    start date
    """

    list_: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="list")] = pydantic.Field(default=None)
    """
    Official list where the entity's risk information or enforcement action is recorded
    """

    program: typing.Optional[str] = pydantic.Field(default=None)
    """
    Specific to sanctions risk. Sanctions program under which the entity is designated.
    """

    reason: typing.Optional[str] = pydantic.Field(default=None)
    """
    Explanation or legal basis for the risk intelligence
    """

    to_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    end date
    """

    type: Tag = pydantic.Field()
    """
    Type of risk intelligence
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
from .project_counts import ProjectCounts
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class Project(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    Unique project identifier.
    """

    label: str = pydantic.Field()
    """
    Most recently set name for the project.
    """

    archived: bool = pydantic.Field()
    """
    Whether the project is archived. Archival is a soft delete.
    """

    created: str
    updated: str
    counts: ProjectCounts

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

TranslationContext = typing.Union[
    typing.Literal["sayari_machine_translation", "pinyin", "google_translate"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .status_context import StatusContext
import pydantic
from .company_status import CompanyStatus
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class StatusProperties(UniversalBaseModel):
    context: typing.Optional[StatusContext] = pydantic.Field(default=None)
    """
    The type of status, such as license or partnership type
    """

    date: typing.Optional[str] = pydantic.Field(default=None)
    """
    as-of date
    """

    from_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    start date
    """

    text: typing.Optional[str] = pydantic.Field(default=None)
    """
    The raw status text
    """

    to_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    end date
    """

    value: typing.Optional[CompanyStatus] = pydantic.Field(default=None)
    """
    The status, normalized to one of the status enums
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...base_types.types.paginated_response import PaginatedResponse
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from ...core.pydantic_utilities import update_forward_refs


class EntityRelationships(PaginatedResponse):
    """
    All relationships the entity is a part of.
    """

    next: typing.Optional[typing.Optional[typing.Any]] = None
    data: typing.List["RelationshipData"]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .entity_details import EntityDetails  # noqa: E402
from .relationship_data import RelationshipData  # noqa: E402

update_forward_refs(EntityDetails, EntityRelationships=EntityRelationships)
update_forward_refs(RelationshipData, EntityRelationships=EntityRelationships)
update_forward_refs(EntityRelationships)
